@@ -4,6 +4,11 @@ from copy import deepcopy
 from decimal import Decimal, getcontext
 from typing import Any, Dict, ItemsView, KeysView, List, Optional, Sequence, TypeVar, Union
 
+try:
+    from vyper.exceptions import DecimalOverrideException
+except ImportError:
+    DecimalOverrideException = BaseException  # regular catch blocks shouldn't catch
+
 import eth_utils
 from hexbytes import HexBytes
 
@@ -182,11 +187,15 @@ def _to_fixed(value: Any) -> Decimal:
         except TypeError:
             pass
     try:
-        ctx = getcontext()
-        ctx.prec = 100
-        return Decimal(value, context=ctx)
-    except Exception:
-        raise TypeError(f"Cannot convert {type(value).__name__} '{value}' to decimal.")
+        try:
+            # until vyper v0.3.1 we can mess with the precision
+            ctx = getcontext()
+            ctx.prec = 78
+        except DecimalOverrideException:
+            pass  # vyper set the precision, do nothing.
+        return Decimal(value)
+    except Exception as e:
+        raise TypeError(f"Cannot convert {type(value).__name__} '{value}' to decimal.") from e
 
 
 class EthAddress(str):
@@ -392,5 +401,5 @@ def _convert_str(value: Any) -> Wei:
         return value
     try:
         return Wei(value)
-    except ValueError:
+    except (ValueError, TypeError):
         return value
